@@ -2,7 +2,7 @@
 Middleware for FastAPI that supports authenticating users against Keycloak
 """
 
-__version__ = "0.1.1"
+__version__ = "0.2.2"
 
 import logging
 
@@ -12,6 +12,7 @@ from fastapi_keycloak_middleware.dependencies.get_authorization_result import (
     get_authorization_result,
 )
 from fastapi_keycloak_middleware.dependencies.get_user import get_user
+from fastapi_keycloak_middleware.fast_api_user import FastApiUser
 from fastapi_keycloak_middleware.middleware import KeycloakMiddleware
 from fastapi_keycloak_middleware.schemas.authorization_methods import (
     AuthorizationMethod,
@@ -30,6 +31,7 @@ __all__ = [
     KeycloakConfiguration.__name__,
     AuthorizationMethod.__name__,
     MatchStrategy.__name__,
+    FastApiUser.__name__,
     get_user.__name__,
     get_authorization_result.__name__,
     require_permission.__name__,
